@@ -20,6 +20,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 操作失败。
 FAILEDOPERATION_CHECKIFSUPPORTPODSTRETCH = 'FailedOperation.CheckIfSupportPodStretch'
 
+# 拉取资源标签失败
+FAILEDOPERATION_DESCRIBERESOURCETAGSFAILED = 'FailedOperation.DescribeResourceTagsFailed'
+
 # 重复的订单，请检查emr控制台。
 FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'
 
@@ -185,6 +188,9 @@ INVALIDPARAMETER_INVALIDEXTENDFIELD = 'InvalidParameter.InvalidExtendField'
 # 无效的任务失败处理策略。
 INVALIDPARAMETER_INVALIDFAILUREPOLICY = 'InvalidParameter.InvalidFailurePolicy'
 
+# 无效过滤参数。
+INVALIDPARAMETER_INVALIDFILTERKEY = 'InvalidParameter.InvalidFilterKey'
+
 # 无效参数，EMR实例不符合要求。
 INVALIDPARAMETER_INVALIDINSTANCE = 'InvalidParameter.InvalidInstance'
 
@@ -287,6 +293,9 @@ INVALIDPARAMETER_INVALIDSOFTWARENAME = 'InvalidParameter.InvalidSoftWareName'
 # 软件版本无效。
 INVALIDPARAMETER_INVALIDSOFTWAREVERSION = 'InvalidParameter.InvalidSoftWareVersion'
 
+# invalid Parameter StartTime or EndTime.参数无效
+INVALIDPARAMETER_INVALIDSTARTTIMEORENDTIME = 'InvalidParameter.InvalidStartTimeOrEndTime'
+
 # 无效的子网ID。
 INVALIDPARAMETER_INVALIDSUBNETID = 'InvalidParameter.InvalidSubnetId'
 
